@@ -32,7 +32,10 @@ def set_lbsn_attr(lbsn_obj, attr_name, in_record, geom: Optional[bool] = None):
     if isinstance(attr_value, (list, dict)):
         if len(attr_value) == 0:
             return
-        getattr(lbsn_obj, attr_name).extend(attr_value)
+        try:
+            getattr(lbsn_obj, attr_name).extend(attr_value)
+        except TypeError:
+            input(f'TypeError: {in_record}')
         return
     if geom:
         attr_value = parse_geom(attr_value)
@@ -322,6 +325,11 @@ class importer():
         set_lbsn_attr(post, "post_url", record)
         post_type = record.get("post_type")
         if post_type:
+            # compatibility: earlier lbsnstructure
+            # had 'carousel' as post type available,
+            # which is now 'image'
+            if post_type == 'carousel':
+                post_type = 'image'
             # get enum value
             post.post_type = lbsn.Post.PostType.Value(
                 post_type.upper())
